@@ -176,24 +176,24 @@ static int       AnyMutexIsLocked  (Sp_AnyMutex *mPtr, Tcl_ThreadId);
  */
 
 static int
-ThreadMutexObjCmd(dummy, interp, objc, objv)
-    ClientData dummy;                   /* Not used. */
-    Tcl_Interp *interp;                 /* Current interpreter. */
-    int objc;                           /* Number of arguments. */
-    Tcl_Obj *const objv[];              /* Argument objects. */
-{
+ThreadMutexObjCmd(
+    ClientData dummy,                  /* Not used. */
+    Tcl_Interp *interp,                /* Current interpreter. */
+    int objc,                          /* Number of arguments. */
+    Tcl_Obj *const objv[]              /* Argument objects. */
+) {
     int opt, ret;
     size_t nameLen;
     const char *mutexName;
     char type;
     SpMutex *mutexPtr;
-
     static const char *cmdOpts[] = {
         "create", "destroy", "lock", "unlock", NULL
     };
     enum options {
         m_CREATE, m_DESTROY, m_LOCK, m_UNLOCK
     };
+    (void)dummy;
 
     /*
      * Syntax:
@@ -352,12 +352,12 @@ ThreadMutexObjCmd(dummy, interp, objc, objv)
  */
 
 static int
-ThreadRWMutexObjCmd(dummy, interp, objc, objv)
-    ClientData dummy;                   /* Not used. */
-    Tcl_Interp *interp;                 /* Current interpreter. */
-    int objc;                           /* Number of arguments. */
-    Tcl_Obj *const objv[];              /* Argument objects. */
-{
+ThreadRWMutexObjCmd(
+    ClientData dummy,                  /* Not used. */
+    Tcl_Interp *interp,                /* Current interpreter. */
+    int objc,                          /* Number of arguments. */
+    Tcl_Obj *const objv[]              /* Argument objects. */
+) {
     int opt, ret;
     size_t nameLen;
     const char *mutexName;
@@ -371,6 +371,7 @@ ThreadRWMutexObjCmd(dummy, interp, objc, objv)
     enum options {
         w_CREATE, w_DESTROY, w_RLOCK, w_WLOCK, w_UNLOCK
     };
+    (void)dummy;
 
     /*
      * Syntax:
@@ -516,12 +517,12 @@ ThreadRWMutexObjCmd(dummy, interp, objc, objv)
  */
 
 static int
-ThreadCondObjCmd(dummy, interp, objc, objv)
-    ClientData dummy;                   /* Not used. */
-    Tcl_Interp *interp;                 /* Current interpreter. */
-    int objc;                           /* Number of arguments. */
-    Tcl_Obj *const objv[];              /* Argument objects. */
-{
+ThreadCondObjCmd(
+    ClientData dummy,                  /* Not used. */
+    Tcl_Interp *interp,                /* Current interpreter. */
+    int objc,                          /* Number of arguments. */
+    Tcl_Obj *const objv[]              /* Argument objects. */
+) {
     int opt, ret, timeMsec = 0;
     size_t nameLen;
     const char *condvName, *mutexName;
@@ -534,6 +535,7 @@ ThreadCondObjCmd(dummy, interp, objc, objv)
     enum options {
         c_CREATE, c_DESTROY, c_NOTIFY, c_WAIT
     };
+    (void)dummy;
 
     /*
      * Syntax:
@@ -684,17 +686,18 @@ ThreadCondObjCmd(dummy, interp, objc, objv)
  */
 
 static int
-ThreadEvalObjCmd(dummy, interp, objc, objv)
-    ClientData dummy;                   /* Not used. */
-    Tcl_Interp *interp;                 /* Current interpreter. */
-    int objc;                           /* Number of arguments. */
-    Tcl_Obj *const objv[];              /* Argument objects. */
-{
+ThreadEvalObjCmd(
+    ClientData dummy,                  /* Not used. */
+    Tcl_Interp *interp,                /* Current interpreter. */
+    int objc,                          /* Number of arguments. */
+    Tcl_Obj *const objv[]              /* Argument objects. */
+) {
     int ret, optx, internal;
     const char *mutexName;
     Tcl_Obj *scriptObj;
     SpMutex *mutexPtr = NULL;
     static Sp_RecursiveMutex evalMutex;
+    (void)dummy;
 
     /*
      * Syntax:
@@ -808,11 +811,12 @@ ThreadEvalObjCmd(dummy, interp, objc, objv)
  */
 
 static Tcl_Obj*
-GetName(int type, void *addrPtr)
+GetName(int type, void *dummy)
 {
     char name[32];
     unsigned int id;
     static unsigned int idcounter;
+    (void)dummy;
 
     Tcl_MutexLock(&initMutex);
     id = idcounter++;
@@ -875,7 +879,7 @@ GetAnyItem(int type, const char *name, size_t len)
 
     Tcl_MutexLock(&bucketPtr->lock);
     hashEntryPtr = Tcl_FindHashEntry(&bucketPtr->handles, name);
-    if (hashEntryPtr != (Tcl_HashEntry*)NULL) {
+    if (hashEntryPtr != NULL) {
         itemPtr = (SpItem*)Tcl_GetHashValue(hashEntryPtr);
         itemPtr->refcnt++;
     }
@@ -929,14 +933,14 @@ PutAnyItem(SpItem *itemPtr)
 static void
 AddAnyItem(int type, const char *handle, size_t len, SpItem *itemPtr)
 {
-    int new;
+    int isNew;
     SpBucket *bucketPtr = GetBucket(type, handle, len);
     Tcl_HashEntry *hashEntryPtr;
 
     Tcl_MutexLock(&bucketPtr->lock);
 
-    hashEntryPtr = Tcl_CreateHashEntry(&bucketPtr->handles, handle, &new);
-    Tcl_SetHashValue(hashEntryPtr, (ClientData)itemPtr);
+    hashEntryPtr = Tcl_CreateHashEntry(&bucketPtr->handles, handle, &isNew);
+    Tcl_SetHashValue(hashEntryPtr, itemPtr);
 
     itemPtr->refcnt = 0;
     itemPtr->bucket = bucketPtr;
@@ -970,7 +974,7 @@ RemoveAnyItem(int type, const char *name, size_t len)
 
     Tcl_MutexLock(&bucketPtr->lock);
     hashEntryPtr = Tcl_FindHashEntry(&bucketPtr->handles, name);
-    if (hashEntryPtr == (Tcl_HashEntry*)NULL) {
+    if (hashEntryPtr == NULL) {
         Tcl_MutexUnlock(&bucketPtr->lock);
         return NULL;
     }
@@ -1059,12 +1063,12 @@ RemoveCondv(const char *name, size_t len)
 /*
  *----------------------------------------------------------------------
  *
- * Sp_Init --
+ * SpInit --
  *
  *      Create commands in current interpreter.
  *
  * Results:
- *      Standard Tcl result.
+ *      NULL
  *
  * Side effects:
  *      Initializes shared hash table for storing sync primitive
@@ -1073,10 +1077,10 @@ RemoveCondv(const char *name, size_t len)
  *----------------------------------------------------------------------
  */
 
-int
-Sp_Init (interp)
-    Tcl_Interp *interp;                 /* Interp where to create cmds */
-{
+const char *
+SpInit (
+    Tcl_Interp *interp                 /* Interp where to create cmds */
+) {
     SpBucket *bucketPtr;
 
     if (!initOnce) {
@@ -1103,7 +1107,7 @@ Sp_Init (interp)
     TCL_CMD(interp, THREAD_CMD_PREFIX"::cond",    ThreadCondObjCmd);
     TCL_CMD(interp, THREAD_CMD_PREFIX"::eval",    ThreadEvalObjCmd);
 
-    return TCL_OK;
+    return NULL;
 }
 
 /*
@@ -1197,7 +1201,7 @@ SpMutexFinalize(SpMutex *mutexPtr)
 {
     Sp_AnyMutex **lockPtr = &mutexPtr->lock;
 
-    if (AnyMutexIsLocked((Sp_AnyMutex*)mutexPtr->lock, (Tcl_ThreadId)0)) {
+    if (AnyMutexIsLocked((Sp_AnyMutex*)mutexPtr->lock, NULL)) {
         return 0;
     }
 
@@ -1265,7 +1269,7 @@ SpCondvWait(SpCondv *condvPtr, SpMutex *mutexPtr, int msec)
 
     condvPtr->mutex = mutexPtr;
 
-    emPtr->owner = (Tcl_ThreadId)0;
+    emPtr->owner = NULL;
     emPtr->lockcount = 0;
 
     Tcl_ConditionWait(&condvPtr->cond, &emPtr->mutex, wt);
@@ -1418,7 +1422,7 @@ Sp_ExclusiveMutexLock(Sp_ExclusiveMutex *muxPtr)
 int
 Sp_ExclusiveMutexIsLocked(Sp_ExclusiveMutex *muxPtr)
 {
-    return AnyMutexIsLocked((Sp_AnyMutex*)*muxPtr, (Tcl_ThreadId)0);
+    return AnyMutexIsLocked((Sp_AnyMutex*)*muxPtr, NULL);
 }
 
 /*
@@ -1454,7 +1458,7 @@ Sp_ExclusiveMutexUnlock(Sp_ExclusiveMutex *muxPtr)
         Tcl_MutexUnlock(&emPtr->lock);
         return 0; /* Not locked */
     }
-    emPtr->owner = (Tcl_ThreadId)0;
+    emPtr->owner = NULL;
     emPtr->lockcount = 0;
     Tcl_MutexUnlock(&emPtr->lock);
 
@@ -1546,7 +1550,7 @@ Sp_RecursiveMutexLock(Sp_RecursiveMutex *muxPtr)
          */
         rmPtr->lockcount++;
     } else {
-        if (rmPtr->owner == (Tcl_ThreadId)0) {
+        if (rmPtr->owner == NULL) {
             /*
              * Nobody holds the mutex, we do now.
              */
@@ -1558,7 +1562,7 @@ Sp_RecursiveMutexLock(Sp_RecursiveMutex *muxPtr)
              */
             while (1) {
                 Tcl_ConditionWait(&rmPtr->cond, &rmPtr->lock, NULL);
-                if (rmPtr->owner == (Tcl_ThreadId)0) {
+                if (rmPtr->owner == NULL) {
                     rmPtr->owner = thisThread;
                     rmPtr->lockcount = 1;
                     break;
@@ -1592,7 +1596,7 @@ Sp_RecursiveMutexLock(Sp_RecursiveMutex *muxPtr)
 int
 Sp_RecursiveMutexIsLocked(Sp_RecursiveMutex *muxPtr)
 {
-    return AnyMutexIsLocked((Sp_AnyMutex*)*muxPtr, (Tcl_ThreadId)0);
+    return AnyMutexIsLocked((Sp_AnyMutex*)*muxPtr, NULL);
 }
 
 /*
@@ -1629,7 +1633,7 @@ Sp_RecursiveMutexUnlock(Sp_RecursiveMutex *muxPtr)
     }
     if (--rmPtr->lockcount <= 0) {
         rmPtr->lockcount = 0;
-        rmPtr->owner = (Tcl_ThreadId)0;
+        rmPtr->owner = NULL;
         if (rmPtr->cond) {
             Tcl_ConditionNotify(&rmPtr->cond);
         }
@@ -1720,7 +1724,7 @@ Sp_ReadWriteMutexRLock(Sp_ReadWriteMutex *muxPtr)
         rwPtr->numrd--;
     }
     rwPtr->lockcount++;
-    rwPtr->owner = (Tcl_ThreadId)0; /* Many threads can read-lock */
+    rwPtr->owner = NULL; /* Many threads can read-lock */
     Tcl_MutexUnlock(&rwPtr->lock);
 
     return 1;
@@ -1801,7 +1805,7 @@ Sp_ReadWriteMutexWLock(Sp_ReadWriteMutex *muxPtr)
 int
 Sp_ReadWriteMutexIsLocked(Sp_ReadWriteMutex *muxPtr)
 {
-    return AnyMutexIsLocked((Sp_AnyMutex*)*muxPtr, (Tcl_ThreadId)0);
+    return AnyMutexIsLocked((Sp_AnyMutex*)*muxPtr, NULL);
 }
 
 /*
@@ -1836,7 +1840,7 @@ Sp_ReadWriteMutexUnlock(Sp_ReadWriteMutex *muxPtr)
     }
     if (--rwPtr->lockcount <= 0) {
         rwPtr->lockcount = 0;
-        rwPtr->owner = (Tcl_ThreadId)0;
+        rwPtr->owner = NULL;
     }
     if (rwPtr->numwr) {
         Tcl_ConditionNotify(&rwPtr->wcond);
@@ -1910,7 +1914,7 @@ AnyMutexIsLocked(Sp_AnyMutex *mPtr, Tcl_ThreadId threadId)
     if (mPtr != NULL) {
         Tcl_MutexLock(&mPtr->lock);
         locked = mPtr->lockcount != 0;
-        if (locked && threadId != (Tcl_ThreadId)0) {
+        if (locked && threadId != NULL) {
             locked = mPtr->owner == threadId;
         }
         Tcl_MutexUnlock(&mPtr->lock);
