@@ -73,7 +73,7 @@ namespace eval ttrace {
     }
 
     # Keep in sync with the Thread package
-    package provide Ttrace 2.8.6
+    package provide Ttrace 2.8.8
 
     # Package variables
     variable resolvers ""     ; # List of registered resolvers
@@ -195,7 +195,7 @@ namespace eval ttrace {
             }
             variable epoch $from
         }
-        uplevel [getscript]
+        uplevel 1 [getscript]
     }
 
     proc getscript {} {
@@ -218,7 +218,7 @@ namespace eval ttrace {
 
     proc cleanup {args} {
         foreach cmd [info commands resolve::cleaner_*] {
-            uplevel $cmd $args
+            uplevel 1 $cmd $args
         }
     }
 
@@ -322,10 +322,10 @@ namespace eval ttrace {
 
     proc unknown {args} {
         set cmd [lindex $args 0]
-        if {[uplevel ttrace::_resolve [list $cmd]]} {
-            set c [catch {uplevel $cmd [lrange $args 1 end]} r]
+        if {[uplevel 1 ttrace::_resolve [list $cmd]]} {
+            set c [catch {uplevel 1 $cmd [lrange $args 1 end]} r]
         } else {
-            set c [catch {::eval ::tcl::unknown $args} r]
+            set c [catch {uplevel 1 ::tcl::unknown $args} r]
         }
         return -code $c -errorcode $::errorCode -errorinfo $::errorInfo $r
     }
@@ -333,7 +333,7 @@ namespace eval ttrace {
     proc _resolve {cmd} {
         variable resolvers
         foreach resolver $resolvers {
-            if {[uplevel [info comm resolve::$resolver] [list $cmd]]} {
+            if {[uplevel 1 [info comm resolve::$resolver] [list $cmd]]} {
                 return 1
             }
         }
@@ -542,7 +542,7 @@ eval {
             return
         }
         set nop [lindex $cmdline 1]
-        set cns [uplevel namespace current]
+        set cns [uplevel 1 namespace current]
         if {$cns == "::"} {
             set cns ""
         }
@@ -614,7 +614,7 @@ eval {
         }
         set opts [lrange $cmdline 1 end]
         if {[llength $opts]} {
-            set cns [uplevel namespace current]
+            set cns [uplevel 1 namespace current]
             if {$cns == "::"} {
                 set cns ""
             }
@@ -662,7 +662,7 @@ eval {
         if {$code != 0} {
             return
         }
-        set cns [uplevel namespace current]
+        set cns [uplevel 1 namespace current]
         if {$cns == "::"} {
             set cns ""
         }
@@ -707,7 +707,7 @@ eval {
         if {$code != 0} {
             return
         }
-        set cns [uplevel namespace current]
+        set cns [uplevel 1 namespace current]
         if {$cns == "::"} {
             set cns ""
         }
@@ -747,15 +747,15 @@ eval {
                 set cmd [lindex $args 0]
                 set hit [lsearch -glob {commands procs args default body} $cmd*]
                 if {$hit > 1} {
-                    if {[catch {uplevel ::tcl::info $args}]} {
-                        uplevel ttrace::_resolve [list [lindex $args 1]]
+                    if {[catch {uplevel 1 ::tcl::info $args}]} {
+                        uplevel 1 ttrace::_resolve [list [lindex $args 1]]
                     }
-                    return [uplevel ::tcl::info $args]
+                    return [uplevel 1 ::tcl::info $args]
                 }
                 if {$hit == -1} {
-                    return [uplevel ::tcl::info $args]
+                    return [uplevel 1 ::tcl::info $args]
                 }
-                set cns [uplevel namespace current]
+                set cns [uplevel 1 namespace current]
                 if {$cns == "::"} {
                     set cns ""
                 }
@@ -774,7 +774,7 @@ eval {
                         set lazy([namespace tail $entry]) 1
                     }
                 }
-                foreach entry [uplevel ::tcl::info $args] {
+                foreach entry [uplevel 1 ::tcl::info $args] {
                     set lazy($entry) 1
                 }
                 array names lazy
@@ -789,7 +789,7 @@ eval {
     #
 
     ttrace::addresolver resolveprocs {cmd {export 0}} {
-        set cns [uplevel namespace current]
+        set cns [uplevel 1 namespace current]
         set name [namespace tail $cmd]
         if {$cns == "::"} {
             set cns ""
@@ -879,7 +879,7 @@ eval {
     }
 
     set resolver [ttrace::addresolver resolveclasses {classname} {
-        set cns [uplevel namespace current]
+        set cns [uplevel 1 namespace current]
         set script [ttrace::getentry xotcl $classname]
         if {$script == ""} {
             set name [namespace tail $classname]
@@ -895,7 +895,7 @@ eval {
                 return 0
             }
         }
-        uplevel [list namespace eval $cns $script]
+        uplevel 1 [list namespace eval $cns $script]
         return 1
     }]
 
